@@ -5,15 +5,20 @@ SPDX-License-Identifier: MIT-0
 
 import warnings
 
+
 def refactored(message):
-    """ Decorator for refactoring classes """
+    """Decorator for refactoring classes"""
+
     def cls_wrapper(cls):
-        """ Wrapper Class """
-        class Wrapped(cls, object):
-            """ Wrapped Class """
+        """Wrapper Class"""
+
+        class Wrapped(cls):
+            """Wrapped Class"""
 
             def __init__(self, *args, **kwargs):
                 warnings.warn(message, FutureWarning)
-                super(Wrapped, self).__init__(*args, **kwargs)
+                super().__init__(*args, **kwargs)
+
         return Wrapped
+
     return cls_wrapper
