@@ -2,7 +2,8 @@
 Copyright Amazon.com, Inc. or its affiliates. All Rights Reserved.
 SPDX-License-Identifier: MIT-0
 """
-import re
+
+import regex as re
 
 from cfnlint.rules import CloudFormationLintRule, RuleMatch
 
